import styled from "@emotion/styled";
import * as PropTypes from "prop-types";
import * as React from "react";
export class Fallback extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            cut: this.props.fontFaces[0],
            activeFallback: undefined
        };
        this.selectCut = (cut) => () => {
            this.setState({ cut });
        };
        this.toggleFallback = (fontFamily) => () => {
            if (this.state.activeFallback === fontFamily) {
                this.setState({ activeFallback: undefined });
            }
            else {
                this.setState({ activeFallback: fontFamily });
            }
        };
    }
    render() {
        const { catalog } = this.context;
        const { fontFaces, sample = defaultSample } = this.props;
        const { cut, activeFallback } = this.state;
        const fontStack = activeFontStack(cut, activeFallback);
        return (React.createElement(Root, { theme: catalog.theme },
            React.createElement(Cuts, { theme: catalog.theme },
                React.createElement("strong", null, "Cut:"),
                " ",
                fontFaces.map((c, i) => (React.createElement(CutOption, { key: i, isActive: c === cut, onClick: this.selectCut(c) }, c.name)))),
            React.createElement(Stack, { theme: catalog.theme },
                React.createElement("strong", null, "Fallback:"),
                " ",
                React.createElement(Option, { theme: catalog.theme, isActive: activeFallback === undefined, onClick: this.toggleFallback(undefined) }, "None"),
                cut.fallback.map((fontFamily, i) => (React.createElement(Option, { key: i, theme: catalog.theme, isActive: activeFallback === fontFamily, onClick: this.toggleFallback(fontFamily) }, fontFamily)))),
            React.createElement(SampleContainer, null,
                React.createElement(Sample, { theme: catalog.theme },
                    React.createElement("div", { style: {
                            ...cut.cssProperties,
                            fontFamily: cut.fontFamily,
                            opacity: activeFallback ? 0.7 : 1,
                            color: activeFallback ? "#BF2626" : undefined
                        } }, sample),
                    activeFallback && (React.createElement(FallbackOverlay, { style: { ...cut.cssProperties, fontFamily: fontStack } }, sample))))));
    }
}
Fallback.contextTypes = {
    catalog: PropTypes.object.isRequired
};
const defaultSample = (React.createElement(React.Fragment, null, "Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur. Excepteur sint occaecat cupidatat non proident, sunt in culpa qui officia deserunt mollit anim id est laborum."));
const Root = styled("div") `
  flex-basis: 100%;
  margin: 24px 0;
`;
const Cuts = styled("div") `
  display: flex;
  color: ${p => p.theme.textColor};
  font-family: ${p => p.theme.fontHeading};
  font-size: ${p => getFontSize(p.theme, 0)};
  line-height: ${p => p.theme.msRatio};
`;
const CutOption = styled("div") `
  font-style: normal;
  font-weight: 400;
  text-rendering: optimizeLegibility;
  opacity: ${p => (p.isActive ? 1 : 0.6)};
  margin-left: 12px;
  cursor: pointer;
  user-select: none;
  text-decoration: ${p => (p.isActive ? "underline" : "none")};

  &:hover {
    opacity: 1;
  }
`;
const Stack = styled("div") `
  display: flex;
  color: ${p => p.theme.textColor};
  font-family: ${p => p.theme.fontHeading};
  font-size: ${p => getFontSize(p.theme, 0)};
  line-height: ${p => p.theme.msRatio};
  margin: 8px 0;
`;
const Option = styled("div") `
  font-style: normal;
  font-weight: 400;
  text-rendering: optimizeLegibility;
  opacity: ${p => (p.isActive ? 1 : 0.6)};
  margin-left: 8px;
  cursor: pointer;
  user-select: none;
  text-decoration: ${p => (p.isActive ? "underline" : "none")};

  &:hover {
    opacity: 1;
  }
`;
const SampleContainer = styled("div") `
  padding: 15px 30px;
  background: white;
  margin: 12px 0;
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.1);
`;
const Sample = styled("div") `
  position: relative;
  color: ${p => p.theme.textColor};
  font-size: ${p => getFontSize(p.theme, 1)};
  line-height: 1.7;

  display: flex;
  flex-direction: column;
`;
const FallbackOverlay = styled("div") `
  position: absolute;
  top: 0;
  left: 0;
  opacity: 0.7;
  color: #008030;
`;
const getFontSize = ({ baseFontSize, msRatio }, level = 0) => `${(baseFontSize / 16) * Math.pow(msRatio, level)}em`;
const activeFontStack = (cut, activeFallback) => {
    const stack = [cut.fontFamily, ...cut.fallback];
    const stackIndex = activeFallback ? stack.indexOf(activeFallback) : 0;
    return stack.slice(stackIndex).join(',');
};
