import styled from "@emotion/styled";
import * as PropTypes from "prop-types";
import * as React from "react";
import { cssFontStack } from "./types";
export class Font extends React.PureComponent {
    constructor(props) {
        super(props);
        this.state = {
            selectedTab: props.sample ? 'SAMPLE' : 'PANGRAM'
        };
    }
    render() {
        const { catalog } = this.context;
        const { name, fontFace, sample, usage, cssProperties } = this.props;
        const { selectedTab } = this.state;
        const fontStack = cssFontStack(fontFace);
        return (React.createElement(Root, null,
            React.createElement(Name, { theme: catalog.theme },
                React.createElement("div", null, name),
                React.createElement(Tabs, null,
                    React.createElement(Tab, { theme: catalog.theme, active: selectedTab === "PANGRAM", onClick: () => {
                            this.setState({ selectedTab: "PANGRAM" });
                        } }, "Pangram"),
                    sample && (React.createElement(Tab, { theme: catalog.theme, active: selectedTab === "SAMPLE", onClick: () => {
                            this.setState({ selectedTab: "SAMPLE" });
                        } }, "Sample")),
                    usage && (React.createElement(Tab, { theme: catalog.theme, active: selectedTab === "USAGE", onClick: () => {
                            this.setState({ selectedTab: "USAGE" });
                        } }, "Usage")),
                    React.createElement(Tab, { theme: catalog.theme, active: selectedTab === "CSS", onClick: () => {
                            this.setState({ selectedTab: "CSS" });
                        } }, "CSS"))),
            React.createElement("div", null,
                React.createElement("div", null,
                    selectedTab === "PANGRAM" && (React.createElement(Pangram, { style: { fontFamily: fontStack, ...fontFace.cssProperties, ...cssProperties } }, "The quick brown fox jumps over the lazy dog")),
                    selectedTab === "SAMPLE" && (React.createElement(Sample, { style: { fontFamily: fontStack, ...fontFace.cssProperties, ...cssProperties } }, sample)),
                    usage && selectedTab === "USAGE" && usage(this.props, { catalog }),
                    selectedTab === "CSS" && React.createElement(ComputedStyle, Object.assign({}, this.props, { catalog: catalog }))))));
    }
}
Font.contextTypes = {
    catalog: PropTypes.object.isRequired
};
const Root = styled("div") `
  flex-basis: 100%;
  margin: 16px 0;
`;
const Name = styled("div") `
  font-style: normal;
  font-weight: 400;
  text-rendering: optimizeLegibility;
  color: ${p => p.theme.brandColor};
  font-family: ${p => p.theme.fontHeading};
  font-size: ${p => getFontSize(p.theme, 1)};
  line-height: ${p => p.theme.msRatio};

  display: flex;
  align-items: baseline;

  margin-bottom: 4px;
`;
const Tabs = styled("div") `
  display: flex;
  align-items: baseline;
  margin-left: 8px;
  margin-bottom: 4px;
`;
const Tab = styled("div") `
  font-style: normal;
  font-weight: 400;
  text-rendering: optimizeLegibility;
  color: ${p => p.theme.brandColor};
  font-family: ${p => p.theme.fontHeading};
  font-size: ${p => getFontSize(p.theme, -3)};
  line-height: ${p => p.theme.msRatio};

  padding: 0 6px;
  color: ${p => (p.active ? p.theme.brandColor : p.theme.brandColor + "88")};

  cursor: pointer;

  transition: all 0.16s;

  &:hover {
    color: ${p => (p.active ? p.theme.brandColor : p.theme.brandColor + "DD")};
  }
`;
const Pangram = styled("div") `
  white-space: nowrap;
`;
const Sample = styled("div") `
  & > *:first-child {
    margin-top: 0;
  }
  & > *:last-child {
    margin-bottom: 0;
  }
`;
const Definition = styled("div") `
  font-style: normal;
  font-weight: 400;
  text-rendering: optimizeLegibility;
  color: ${p => p.theme.textColor + "AA"};
  font-family: ${p => p.theme.fontHeading};
  font-size: ${p => getFontSize(p.theme, 0)};
  line-height: ${p => p.theme.msRatio};
  line-height: 1.5;
  padding: 20px;
  background: white;
  box-shadow: 0 0 1px 0 rgba(0, 0, 0, 0.1);

  dl {
    margin: 2px 0 2px 20px;
  }
  dt {
    display: inline-block;
  }
  dd {
    display: inline-block;
    margin-left: 8px;
    color: ${p => p.theme.textColor};
  }
`;
const getFontSize = ({ baseFontSize, msRatio }, level = 0) => `${(baseFontSize / 16) * Math.pow(msRatio, level)}em`;
const toKebabCase = (str) => str.replace(/([a-z0-9])([A-Z])/g, "$1-$2").toLowerCase();
export const fontUsageCSS = ({ cssProperties }, { catalog }) => (React.createElement(Definition, { theme: catalog.theme },
    ".selector ",
    "{",
    React.createElement("dl", null, Object.keys(cssProperties)
        .sort()
        .map(k => (React.createElement("div", { key: k },
        React.createElement("dt", null,
            toKebabCase(k),
            ":"),
        React.createElement("dd", null,
            cssProperties[k],
            ";"))))),
    "}"));
class ComputedStyle extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {
            style: undefined
        };
        this.extractComputedProperties = (ref) => {
            if (ref) {
                const style = window.getComputedStyle(ref);
                this.setState({ style });
            }
        };
    }
    render() {
        const { name, fontFace, cssProperties, catalog } = this.props;
        const { style } = this.state;
        const fontStack = cssFontStack(fontFace);
        const relevantProperties = {};
        if (style) {
            for (const s in style) {
                if (typeof s === "string" && s.match(/^(font[A-Z]|lineHeight)/)) {
                    const value = style[s];
                    if (value && (value !== "normal" && value !== "auto" && value !== "100%")) {
                        relevantProperties[s] = value;
                    }
                }
            }
        }
        return (React.createElement(React.Fragment, null,
            React.createElement("div", { style: { fontFamily: fontStack, ...fontFace.cssProperties, ...cssProperties }, ref: this.extractComputedProperties }),
            React.createElement(Definition, { theme: catalog.theme },
                ".",
                name,
                " ",
                "{",
                React.createElement("dl", null, Object.keys(relevantProperties)
                    .sort()
                    .map(k => (React.createElement("div", { key: k },
                    React.createElement("dt", null,
                        toKebabCase(k),
                        ":"),
                    React.createElement("dd", null,
                        relevantProperties[k],
                        ";"))))),
                "}")));
    }
}
