/**
 * Render a FontFace's fontFamily and fallback font families as a CSS font stack
 * string for use with the CSS font-family property.
 *
 * @example
 * const fontFace = { fontFamily: 'Tuna', fallback: ['Roboto Slab', 'serif'], ... }
 * cssFontStack(fontFace) // "Tuna, 'Roboto Slab', serif"
 */
export const cssFontStack = (fontFace) => {
    const hasSpaces = /\s+/;
    const wrapInQuotes = (x) => hasSpaces.test(x) ? `"${x}"` : x;
    return [fontFace.fontFamily, ...fontFace.fallback].map(wrapInQuotes).join(',');
};
